pub struct AbstractMockQuerierBuilder { /* private fields */ }Implementations
sourceimpl AbstractMockQuerierBuilder
impl AbstractMockQuerierBuilder
sourcepub fn account(self, manager: &str, proxy: &str, account_id: u32) -> Self
pub fn account(self, manager: &str, proxy: &str, account_id: u32) -> Self
Mock the existence of an Account by setting the Account id for the proxy and manager along with registering the account to version control.
sourcepub fn assets(self, assets: Vec<(&AssetEntry, AssetInfo)>) -> Self
pub fn assets(self, assets: Vec<(&AssetEntry, AssetInfo)>) -> Self
Add mock assets into ANS
sourcepub fn set_version_control(self, version_control: &'static str) -> Self
pub fn set_version_control(self, version_control: &'static str) -> Self
Change the version control address. Any account added after this will be registered to this address.
pub fn ans(self, _ans: MockAnsHost) -> Self
pub fn builder(self) -> MockQuerierBuilder
pub fn build(self) -> MockQuerier